import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import {
  csv,
  scaleLinear,
  scaleBand,
  scaleOrdinal,
  line,
  max,
  timeFormat,
  extent,
  histogram as bin,
  timeMonths,
  sum
} from 'd3';
import ReactDropdown from 'react-dropdown';
import { ColorLegend } from './ColorLegend';
import { useData } from './useData';
import { AxisBottom } from './AxisBottom';
import { AxisLeft } from './AxisLeft';
import { Marks } from './Marks';
import {MarksLine} from './MarksLine'

const width = 960;
const menuHeight = 80;
const height = 500 - menuHeight;
const margin = { top: 40, right: 100, bottom: 40, left: 90 };
const xAxisLabelOffset = 65;
const yAxisLabelOffset = 30;

const team = ["DAL","DEN","GSW","HOU","LAC","LAL","PHX","POR","UTA","MEM","MIN","NOP","OKC","SAC","SAS",
              "BKN","BOS","CHI","CLE","MIA","MIL","NYK","ORL","PHI","ATL","CHA","DET","IND","TOR","WAS"]
    

const Xattributes=[];

for(let j = 0; j < team.length; j++) {
  const attr = {value:team[j],label:team[j]};
  Xattributes.push(attr);
} 

const getLabel = value => {
  for (let i = 0; i < Xattributes.length; i++) {
    if (Xattributes[i].value === value) {
      return Xattributes[i].label;
    }
  }
};

//const Yattributes=[];

const App = () => {
  const data = useData();
  
  const initialXAttribute = 'DAL';
  const [xAttribute, setXAttribute] = useState(initialXAttribute);
  const initialYAttribute = 'Luka Doncic'
  const [yAttribute, setYAttribute] = useState(initialYAttribute);
  //const xValue = d => d[xAttribute];
  //const xAxisLabel = getLabel(xAttribute);

  if (!data) {
    return <pre>Loading...</pre>;
  }

  const data1 = data.filter(function (d) {
    return d.TEAM == xAttribute;
  });
  
  const firstPLY = data1[0].PLAYER;
  console.log(firstPLY)
  
  const Yattributes=[];
  for(let j = 0; j < data1.length; j++) {
    const attr = {value:data1[j].PLAYER,label:data1[j].PLAYER};
    Yattributes.push(attr);
  } 
  const dataPLY = data1.filter(function (d) {
    return d.PLAYER == yAttribute;
  });
  
  console.log(Yattributes)
  console.log(dataPLY)

  const xValue = (d) => d.PLAYERX;
  const xAxisLabel = 'Player';

  const yValue = (d) => d.GP;
  const yAxisLabel = 'Game Played';
  
  const ptsValue = (d) => d.PTS;
  const rebValue = (d) => d.REB;
  const astValue = (d) => d.AST;
  const stlValue = (d) => d.STL;
  const blkValue = (d) => d.BLK;
  const tovValue = (d) => d.TOV;
  
  const colorLegendLabel = 'Color Index'
  const colorScale = scaleOrdinal()
  	.domain(['Wins','Loses'])
  	.range(['lightgreen','lightcoral'])

  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;
  
  const radiusRange = 5/9 * innerHeight

  const ptsScale = scaleLinear()
    .domain([0, max(data1, (d) => d.PTS)])
    .range([0,radiusRange]);
  const rebScale = scaleLinear()
    .domain([0, max(data1, (d) => d.REB)])
    .range([0,radiusRange]);
  const astScale = scaleLinear()
    .domain([0, max(data1, (d) => d.AST)])
    .range([0,radiusRange]);
  const stlScale = scaleLinear()
    .domain([0, max(data1, (d) => d.STL)])
    .range([0,radiusRange]);
  const blkScale = scaleLinear()
    .domain([0, max(data1, (d) => d.BLK)])
    .range([0,radiusRange]);
  const tovScale = scaleLinear()
    .domain([0, max(data1, (d) => d.TOV)])
    .range([0,radiusRange]);
  
  const ptsxPos = (d) => innerWidth/2+ptsScale(ptsValue(d))*Math.cos(0*Math.PI/3);
  const ptsyPos = (d) => (height-margin.top)/2+ptsScale(ptsValue(d))*Math.sin(0*Math.PI/3);
  const rebxPos = (d) => innerWidth/2+rebScale(rebValue(d))*Math.cos(1*Math.PI/3);
  const rebyPos = (d) => (height-margin.top)/2+rebScale(rebValue(d))*Math.sin(1*Math.PI/3);
  const astxPos = (d) => innerWidth/2+astScale(astValue(d))*Math.cos(2*Math.PI/3);
  const astyPos = (d) => (height-margin.top)/2+astScale(astValue(d))*Math.sin(2*Math.PI/3);
  const stlxPos = (d) => innerWidth/2+stlScale(stlValue(d))*Math.cos(3*Math.PI/3);
  const stlyPos = (d) => (height-margin.top)/2+stlScale(stlValue(d))*Math.sin(3*Math.PI/3);
  const blkxPos = (d) => innerWidth/2+blkScale(blkValue(d))*Math.cos(4*Math.PI/3);
  const blkyPos = (d) => (height-margin.top)/2+blkScale(blkValue(d))*Math.sin(4*Math.PI/3);
  const tovxPos = (d) => innerWidth/2+tovScale(tovValue(d))*Math.cos(5*Math.PI/3);
  const tovyPos = (d) => (height-margin.top)/2+tovScale(tovValue(d))*Math.sin(5*Math.PI/3);
  
  const marks = [];

  const pstPos = dataPLY.map((d)=>({
  	x:ptsxPos(d),
    y:ptsyPos(d)
  }));
  
  
  const rebPos = dataPLY.map((d)=>({
  	x:rebxPos(d),
    y:rebyPos(d)
  }));
  
  
  const astPos = dataPLY.map((d)=>({
  	x:astxPos(d),
    y:astyPos(d)
  }));
  
  
  const stlPos = dataPLY.map((d)=>({
  	x:stlxPos(d),
    y:stlyPos(d)
  }));
  
  
  const blkPos = dataPLY.map((d)=>({
  	x:blkxPos(d),
    y:blkyPos(d)
  }));
  
  
  const tovPos = dataPLY.map((d)=>({
  	x:tovxPos(d),
    y:tovyPos(d)
  }));
  
  
  console.log(dataPLY.length)
  if(dataPLY.length == 0){
    marks.push({x:0,y:0})  
  }else{
  	marks.push(pstPos[0])
    marks.push(rebPos[0])
    marks.push(astPos[0])
    marks.push(stlPos[0])
    marks.push(blkPos[0])
    marks.push(tovPos[0])
  	marks.push(pstPos[0])
  }
  
  
  console.log(marks)
  
  
  const path = d3.line()
  							.x(d=>d.x)
  							.y(d=>d.y);
  console.log(path(marks))
  
  
  return (
    <>
      <div className="menus-container">
          <span className="dropdown-label">Team:</span>
          <ReactDropdown
            options={Xattributes}
            value={xAttribute}
            onChange={({ value }) => {
            	setXAttribute(value)
            	setYAttribute('')
          		}
            }
          />
          <span className="dropdown-label">Player:</span>
          <ReactDropdown
            options={Yattributes}
            value={yAttribute}
            onChange={({ value }) => setYAttribute(value)}
          />
      </div>
      <svg width={width} height={height}>
        <g transform={`translate(${margin.left},${margin.top})`}>
           <AxisBottom
              xScale={ptsScale}
              x={innerWidth/2}
              y={innerHeight}
              leftMargin={margin.left}
              //tickFormat={xAxisTickFormat}
             	maxRadius={radiusRange}
              tickOffset={25}
              angle={Math.PI*0}
            />
          <AxisBottom
            xScale={rebScale}
            x={innerWidth/2}
            y={innerHeight}
            leftMargin={margin.left}
            //tickFormat={xAxisTickFormat}
            maxRadius={radiusRange}
            tickOffset={25}
            angle={Math.PI/3}
          />
          <AxisBottom
            xScale={astScale}
            x={innerWidth/2}
            y={innerHeight}
            leftMargin={margin.left}
            //tickFormat={xAxisTickFormat}
            maxRadius={radiusRange}
            tickOffset={25}
            angle={2*Math.PI/3}
          />
          <AxisBottom
            xScale={stlScale}
            x={innerWidth/2}
            y={innerHeight}
            leftMargin={margin.left}
            //tickFormat={xAxisTickFormat}
            maxRadius={radiusRange}
            tickOffset={25}
            angle={Math.PI}
          />
          <AxisBottom
            xScale={blkScale}
            x={innerWidth/2}
            y={innerHeight}
            leftMargin={margin.left}
            //tickFormat={xAxisTickFormat}
            maxRadius={radiusRange}
            tickOffset={25}
            angle={4*Math.PI/3}
          />
          <AxisBottom
            xScale={tovScale}
            x={innerWidth/2}
            y={innerHeight}
            leftMargin={margin.left}
            //tickFormat={xAxisTickFormat}
            maxRadius={radiusRange}
            tickOffset={25}
            angle={5*Math.PI/3}
          />
          
          <line 
            x1={innerWidth/2+radiusRange*Math.cos(Math.PI)} 
            y1={(height-margin.top)/2+radiusRange*Math.sin(Math.PI)} 
            x2={innerWidth/2+radiusRange*Math.cos(0*Math.PI)} 
            y2={(height-margin.top)/2+radiusRange*Math.sin(0*Math.PI)}
            stroke="black"
          />
          
          <line 
            x1={innerWidth/2+radiusRange*Math.cos(Math.PI/3)} 
            y1={(height-margin.top)/2+radiusRange*Math.sin(Math.PI/3)} 
            x2={innerWidth/2+radiusRange*Math.cos(4*Math.PI/3)} 
            y2={(height-margin.top)/2+radiusRange*Math.sin(4*Math.PI/3)}
            stroke="black"
          />
          
          <line 
            x1={innerWidth/2+radiusRange*Math.cos(2*Math.PI/3)} 
            y1={(height-margin.top)/2+radiusRange*Math.sin(2*Math.PI/3)} 
            x2={innerWidth/2+radiusRange*Math.cos(5*Math.PI/3)} 
            y2={(height-margin.top)/2+radiusRange*Math.sin(5*Math.PI/3)}
            stroke="black"
          />
          
          <circle
          	cx={innerWidth/2}  
            cy={(height-margin.top)/2}
            r={1/8*radiusRange}
            fill="none"
            stroke="#A9A9A9"
          />
          
          <circle
          	cx={innerWidth/2}  
            cy={(height-margin.top)/2}
            r={2/8*radiusRange}
            fill="none"
            stroke="#A9A9A9"
          />
          
          <circle
          	cx={innerWidth/2}  
            cy={(height-margin.top)/2}
            r={3/8*radiusRange}
            fill="none"
            stroke="#A9A9A9"
          />
          
          <circle
          	cx={innerWidth/2}  
            cy={(height-margin.top)/2}
            r={4/8*radiusRange}
            fill="none"
            stroke="#A9A9A9"
          />
          
          <circle
          	cx={innerWidth/2}  
            cy={(height-margin.top)/2}
            r={5/8*radiusRange}
            fill="none"
            stroke="#A9A9A9"
          />
          
          <circle
          	cx={innerWidth/2}  
            cy={(height-margin.top)/2}
            r={6/8*radiusRange}
            fill="none"
            stroke="#A9A9A9"
          />
          
          <circle
          	cx={innerWidth/2}  
            cy={(height-margin.top)/2}
            r={7/8*radiusRange}
            fill="none"
            stroke="#A9A9A9"
          />
          
          <circle
          	cx={innerWidth/2}  
            cy={(height-margin.top)/2}
            r={8/8*radiusRange}
            fill="none"
            stroke="#A9A9A9"
          />
           
          
          <path 
            d={path(marks)}
            stroke={"PaleVioletRed"}
            fill={"Pink"}
            opacity="0.7"
            stroke-width="3"
          />
          
          <Marks 
            data={dataPLY}
            ptsScale={ptsScale}
            ptsValue={ptsValue}
            rebScale={rebScale}
            rebValue={rebValue}
            astScale={astScale}
            astValue={astValue}
            stlScale={stlScale}
            stlValue={stlValue}
            blkScale={blkScale}
            blkValue={blkValue}
            tovScale={tovScale}
            tovValue={tovValue}
            innerWidth={innerWidth}
            height={height-margin.top}
            line={path}
            fillColor={"Pink"}
            lineColor={"PaleVioletRed"}
          />
          
        </g>
        
      </svg>
    </>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);

