import {
  csv,
  select,
  scaleLinear,
  scaleSequential,
  scaleBand,
  interpolatePuRd,
  extent,
  axisLeft,
  axisBottom,
  max,
  mean,
  line,
} from 'd3';

const csvUrl = [
        'https://gist.githubusercontent.com/',
        'yichenlilyc/', // User
        'e82f39f103162cda7efc2c5662e203fd/', // Id of the Gist
        'raw/d526302025813404d685b25e80dfce8b8774276d/', // commit
        'NBAPlayerState.csv', // File name
      ].join('');
const parseRow = (d) => {
  d.PTS = +d.PTS;
  d.REB = +d.REB;
  d.OREB = +d.OREB;
  d.DREB = +d.DREB;
  const playerName = d.PLAYER.split(' ');

  d.PLAYERX = playerName[0] + '.' + playerName[1][0];
  //console.log(d.PLAYER);
  return d;
};
const xValue = (d) => d.PLAYERX;
const yValue = (d) => d.PTS;
const yValueO = (d) => d.OREB;
const yValueD = (d) => d.DREB;
const margin = {
  top: 70,
  right: 60,
  bottom: 50,
  left: 60,
};
const radius = 5;

const width = window.innerWidth;
const height = window.innerHeight;
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

const main = async () => {
  const data = await csv(csvUrl, parseRow);
  const data1 = data.filter(function (d) {
    return d.TEAM == 'LAL';
  });
  const sortedData1 = data1.sort((a,b) => d3.descending(a.PTS,b.PTS))
  
  const ptsmean = mean(data1, (d) => d.PTS);
  console.log(ptsmean);

  const x = scaleBand()
    .domain(data1.map((d) => d.PLAYERX))
    .range([margin.left, width - margin.right]);

  const y = scaleLinear()
    .domain([0, max(data1, (d) => d.PTS) + 2])
    .range([height - margin.bottom, margin.top]);

  const effColor = scaleSequential()
    .domain([1, 10])
    .interpolator(interpolatePuRd);

  const marks = data1.map((d) => ({
    x: x(xValue(d)),
    y: y(yValue(d)),
  }));
  
  svg
    .selectAll('rect')
    .data(data1)
    .enter()
  	.append('rect')
  	.attr('class','bar')
    .attr('width', (d) => 40)
    .attr('height', (d) => y(0)-y(yValue(d)))
    .attr('x', (d) => x(xValue(d)) + 5)
    .attr('y', (d) => y(yValue(d)))
    .attr('fill', 'steelblue')
    .append('title')
  	.text((d)=>d.PLAYER+":"+d.PTS)

  const lineGenerator = line()([
    [margin.left, y(ptsmean)],
    [width - margin.right, y(ptsmean)],
  ]);

  svg
    .append('path')
    .attr('d', lineGenerator)
    .attr('stroke', 'crimson')
    .attr('stroke-width', '2');

  svg
    .append('g')
    .attr('transform', `translate(${margin.left},0)`)
    .call(axisLeft(y));

  svg
    .append('g')
    .attr(
      'transform',
      `translate(0,${height - margin.bottom})`
    )
    .call(axisBottom(x))
    .selectAll('text')
    .attr(
      'transform',
      'translate(-10,13)rotate(-45)'
    );

  svg
    .append('text')
  	.attr('font-family', 'Helvetica')
  	.attr('font-size', 20)
    .attr('x', width-margin.right-10)
    .attr('y', height - margin.bottom + 30)
    .text('Player');

  svg
    .append('text')
  	.attr('font-family', 'Helvetica')
  	.attr('font-size', 20)
    .attr('x', margin.left -50)
    .attr('y', margin.top -10)
    .text('Score');

  svg
    .append('text')
  	.attr('font-family', 'Helvetica')
    .attr('x', width - margin.right - 50)
    .attr('y', y(ptsmean) - 10)
    .attr('fill', 'crimson')
    .text('Mean = ' + ptsmean.toFixed(2).toString());
  
  svg
    .append('text')
  	.attr('font-family', 'Helvetica')
  	.attr('font-size', 30)
    .attr('x', 260)
    .attr('y', margin.top - 20)
    .text('LAL NBA Player Scoring Bar Chart');
};
main();